==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/ArrayLengthAccessSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ArrayLengthAccess;
import io.ciera.tool.sql.architecture.expression.ArrayLengthAccessSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.List;


public class ArrayLengthAccessSetImpl extends InstanceSet<ArrayLengthAccessSet,ArrayLengthAccess> implements ArrayLengthAccessSet {

    // attributes
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setExpression_number( ref_expression_number );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setBlock_number( ref_block_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setParent_package( ref_parent_package );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setParent_name( ref_parent_name );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setStatement_number( ref_statement_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setBody_name( ref_body_name );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayLengthAccess arraylengthaccess : this ) expressionset.add( arraylengthaccess.R776_is_a_Expression() );
        return expressionset;
    }


    @Override
    public ArrayLengthAccess nullElement() {
        return ArrayLengthAccessImpl.EMPTY_ARRAYLENGTHACCESS;
    }

    @Override
    public ArrayLengthAccessSet emptySet() {
      return new ArrayLengthAccessSetImpl();
    }

    @Override
    public ArrayLengthAccessSet value() {
        return this;
    }

    @Override
    public List<ArrayLengthAccess> elements() {
        return Arrays.asList(toArray(new ArrayLengthAccess[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/ArrayLengthAccessSetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.ArrayLengthAccess;
import io.ciera.tool.sql.architecture.expression.ArrayLengthAccessSet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ArrayLengthAccessSetImpl extends InstanceSet<ArrayLengthAccessSet,ArrayLengthAccess> implements ArrayLengthAccessSet {

    public ArrayLengthAccessSetImpl() {
    }

    public ArrayLengthAccessSetImpl(Comparator<? super ArrayLengthAccess> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setBlock_number( ref_block_number );
    }
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setStatement_number( ref_statement_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setParent_name( ref_parent_name );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setBody_name( ref_body_name );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setExpression_number( ref_expression_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( ArrayLengthAccess arraylengthaccess : this ) arraylengthaccess.setParent_package( ref_parent_package );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( ArrayLengthAccess arraylengthaccess : this ) expressionset.add( arraylengthaccess.R776_is_a_Expression() );
        return expressionset;
    }


    @Override
    public ArrayLengthAccess nullElement() {
        return ArrayLengthAccessImpl.EMPTY_ARRAYLENGTHACCESS;
    }

    @Override
    public ArrayLengthAccessSet emptySet() {
      return new ArrayLengthAccessSetImpl();
    }

    @Override
    public ArrayLengthAccessSet emptySet(Comparator<? super ArrayLengthAccess> comp) {
      return new ArrayLengthAccessSetImpl(comp);
    }

    @Override
    public ArrayLengthAccessSet value() {
        return this;
    }

    @Override
    public List<ArrayLengthAccess> elements() {
        return Arrays.asList(toArray(new ArrayLengthAccess[0]));
    }

}
